*==============================================================================
* Program:			AddNetConnection
* Purpose:			Maps a network resource to a local device
* Author:			Doug Hennig
* Copyright:		(c) 2001 Stonefield Systems Group Inc.
* Last revision:	01/21/2001
* Parameters:		tcResource - the network resource name
*					tcDevice   - the device name
*					tcPassword - the password for the connection (optional: if
*						it isn't specified, the user should already be
*						validated on the server
* Returns:			.T. if it succeeded
* Environment in:	the specified device must not already be mapped
* Environment out:	if successful, the local device is mapped to the network
*						resource
*==============================================================================

lparameters tcResource, ;
	tcDevice, ;
	tcPassword
local lcPassword, ;
	llReturn

* Ensure valid parameters were passed.

assert vartype(tcResource) = 'C' and not empty(tcResource) ;
	message 'Invalid network resource name'
assert vartype(tcDevice) = 'C' and not empty(tcDevice) ;
	message 'Invalid local device name'

* If the password wasn't specified, use a blank.

lcPassword = iif(vartype(tcPassword) <> 'C', '', tcPassword)

* Declare and call the API function and return the result.

declare integer WNetAddConnection in Win32API ;
	string lpRemoteName, string lpPassword, string lpLocalName
llReturn = WNetAddConnection(tcResource, lcPassword, tcDevice) = 0
return llReturn
