*==============================================================================
* Program:			GetDriveSpace
* Purpose:			Returns the total or free space on a drive; workaround for
*						a bug in VFP's DISKSPACE() routine which doesn't handle
*						free space more than 2 GB
* Author:			Doug Hennig, from code written by George Tasker
* Copyright:		(c) 2001 Stonefield Systems Group Inc.
* Last revision:	02/08/2001
* Parameters:		tcDirectory - any directory on the drive to check space for
*						(optional: if it isn't specified, the current drive is
*						used)
*					tlTotal     - .T. to return the total space on the drive or
*						.F. to return the free space
* Returns:			the amount of free or total space, depending on tlTotal, or
*						-1 if an error occurred (such as drive not ready)
* Environment in:	none
* Environment out:	none
*==============================================================================

lparameters tcDirectory, ;
	tlTotal
local lcDir, ;
	lnResult, ;
	lcDLL, ;
	lnFunction, ;
	lnHandle, ;
	lcCaller, ;
	lcTotal, ;
	lcFree

* Declare Win32API functions to determine if the GetDiskFreeSpaceEx function is
* available.

declare integer GetModuleHandle in Win32API ;
	string @lpModuleName
declare integer GetProcAddress in Win32API ;
	integer hModule, string @lpProcName

* If the path wasn't specified, use the current drive. Otherwise, get the drive
* for the specified path, handling UNC paths specially.

do case
	case vartype(tcDirectory) <> 'C' or empty(tcDirectory)
		lcDir = addbs(sys(5))
	case left(tcDirectory, 2) = '\\'
		lcDir = addbs(tcDirectory)
		lcDir = left(lcDir, at('\', lcDir, 4))
	case len(tcDirectory) = 1
		lcDir = tcDirectory + ':'
	otherwise
		lcDir = addbs(justdrive(tcDirectory))
endcase
lnResult = -1

* See if the GetDiskFreeSpaceEx Win32API function is available; if so, call it
* to get the drive space.

lcDLL      = 'kernel32.dll'
lcFunction = 'GetDiskFreeSpaceExA'
lnHandle   = GetModuleHandle(@lcDLL)
if GetProcAddress(lnHandle, @lcFunction) > 0
	declare short GetDiskFreeSpaceEx in Win32API ;
		string @lpDirectoryName, ;
		string @lpFreeBytesAvailableToCaller, ;
		string @lpTotalNumberOfBytes, ;
		string @lpTotalNumberOfFreeBytes
	store replicate(chr(0), 8) to lcCaller, lcTotal, lcFree
	if GetDiskFreeSpaceEx(@lcDir, @lcCaller, @lcTotal, @lcFree) <> 0
		lnResult = Hex2Decimal(iif(tlTotal, lcTotal, lcFree))
	endif GetDiskFreeSpaceEx(@lcDir, ...

* Since we can't use GetDiskFreeSpaceEx, just use DISKSPACE.

else
	lnResult = diskspace(lcDir)
endif GetProcAddress(lnHandle, @lcFunction) > 0
return lnResult
